@@ -19,8 +19,8 @@
 ;; Created:  2026-01-05
 ;; Keywords: lisp
 ;; URL:      https://github.com/meedstrom/system-idle
-;; Package-Version: 20260207.2244
-;; Package-Revision: 7522fdf0fc60
+;; Package-Version: 20260210.1506
+;; Package-Revision: 876f93dbc00b
 ;; Package-Requires: ((emacs "29.1"))
 
 ;;; Commentary:
@@ -66,12 +66,32 @@
 (declare-function dbus-call-method "dbus" (bus service path interface method &rest args))
 (declare-function dbus-get-property "dbus" (bus service path interface property))
 
-(defun system-idle--poll-mac ()
+;;;;; MacOS:
+
+(defun system-idle--poll-mac-alt ()
   "Copy of `org-mac-idle-seconds'."
   (string-to-number
    (shell-command-to-string
     "ioreg -c IOHIDSystem | perl -ane 'if (/Idle/) {$idle=(pop @F)/1000000000; print $idle; last}'")))
 
+;; https://old.reddit.com/r/emacs/comments/1qzj8bh/a_little_library_systemidle/o4h5qh8/
+(defconst system-idle--poll-mac-re (rx "HIDIdleTime" (* (not digit)) (group (+ digit))))
+(defun system-idle--poll-mac ()
+  "Get idle time on MacOS."
+  (let ((match (save-match-data
+                 (with-temp-buffer
+                   (when (eq 0 (call-process "ioreg" nil t nil "-r" "-k" "HIDIdleTime"))
+                     (goto-char (point-min))
+                     (when (re-search-forward system-idle--poll-mac-re nil t)
+                       (match-string 1)))))))
+    (if match
+        (/ (string-to-number match)
+           (float 1e9))
+      (setq system-idle-seconds-function #'system-idle--poll-mac-alt)
+      (system-idle--poll-mac-alt))))
+
+;;;;; x11idle:
+
 (defvar system-idle--x11-program nil)
 (defun system-idle--poll-x11 ()
   "Like `org-x11-idle-seconds'."
@@ -79,11 +99,14 @@
     (error "system-idle-seconds-x11: Install x11idle or xprintidle"))
   (with-temp-buffer
     (if (eq 0 (call-process system-idle--x11-program nil t))
-        (/ (string-to-number (buffer-string)) 1000)
+        (/ (string-to-number (buffer-string))
+           (float 1e3))
       (error "system-idle-seconds-x11: %s failed: %s"
              system-idle--x11-program
              (buffer-string)))))
 
+;;;;; elogind (and systemd-logind?):
+
 (defvar system-idle--dbus-session-path nil
   "Copy of `org-logind-dbus-session-path'.")
 
@@ -95,13 +118,15 @@
                            system-idle--dbus-session-path
                            "org.freedesktop.login1.Session"
                            "IdleSinceHint")
-        1e6)))
+        (float 1e6))))
+
+;;;;; GNOME:
 
 ;; https://unix.stackexchange.com/questions/396911/how-can-i-tell-if-a-user-is-idle-in-wayland
 (defun system-idle--poll-gnome ()
   "Check Mutter\\='s idea of idle time, even on Wayland."
   (let* ((output (with-temp-buffer
-                   (call-process "dbus-send" nil (current-buffer) nil
+                   (call-process "dbus-send" nil t nil
                                  "--print-reply"
                                  "--dest=org.gnome.Mutter.IdleMonitor"
                                  "/org/gnome/Mutter/IdleMonitor/Core"
@@ -110,7 +135,9 @@
          (idle-ms (if (string-match (rx space (+ digit) eol) output)
                       (string-to-number (match-string 0 output))
                     (error "system-idle--poll-gnome: Broken, did GNOME change API?"))))
-    (/ idle-ms 1000.0)))
+    (/ idle-ms (float 1e3))))
+
+;;;;; Swayidle:
 
 (defvar system-idle--swayidle-process nil)
 (defvar system-idle--touch-me-file
@@ -127,6 +154,8 @@ RESTART means restart it."
             (start-process-shell-command
              "system-idle-swayidle"
              " *system-idle-swayidle*"
+             ;; TODO: Add an instruction to also touch the file when the
+             ;; system is manually put to sleep.
              (format "swayidle timeout 9 'touch %s' resume 'rm -f %s'"
                      (shell-quote-argument system-idle--touch-me-file)
                      (shell-quote-argument system-idle--touch-me-file)))))
